changeset 35569:5cd8ebba5a94

doc&comment fix
author Sam Steingold <sds@gnu.org>
date Thu, 25 Jan 2001 16:36:48 +0000
parents 1a9a88614b73
children 4308e62b25c8
files lisp/ChangeLog lisp/vc-cvs.el
diffstat 2 files changed, 27 insertions(+), 21 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Thu Jan 25 16:01:56 2001 +0000
+++ b/lisp/ChangeLog	Thu Jan 25 16:36:48 2001 +0000
@@ -1,3 +1,7 @@
+2001-01-25  Sam Steingold  <sds@gnu.org>
+
+	* vc-cvs.el (vc-cvs-mode-line-string): Doc & comment fix.
+
 2001-01-25  Stefan Monnier  <monnier@cs.yale.edu>
 
 	* smerge-mode.el (smerge-font-lock-keywords): Relax submatch 1.
@@ -20,7 +24,7 @@
 	* international/mule-conf.el (coding-category-utf-8): Initialize
 	to mule-utf-8.
 
-	* loadup.el: Preload international/utf-8. 
+	* loadup.el: Preload international/utf-8.
 
 	* international/utf-8.el: New file.
 
@@ -33,8 +37,10 @@
 	* dired.el (dired-replace-in-string): Removed.
 	(dired-sort-toggle): Use `replace-regexps-in-string'
 	instead of `dired-replace-in-string'.
+
 	* dired-aux.el (dired-shell-stuff-it, dired-rename-subdir,
 	dired-rename-subdir-2, dired-insert-subdir-doinsert): Ditto.
+
 	* gs.el (gs-replace-in-string): Removed.
 	(gs-options): Use `replace-regexps-in-string'
 	instead of `gs-replace-in-string'.
--- a/lisp/vc-cvs.el	Thu Jan 25 16:01:56 2001 +0000
+++ b/lisp/vc-cvs.el	Thu Jan 25 16:36:48 2001 +0000
@@ -5,7 +5,7 @@
 ;; Author:      FSF (see vc.el for full credits)
 ;; Maintainer:  Andre Spiegel <spiegel@gnu.org>
 
-;; $Id: vc-cvs.el,v 1.14 2001/01/08 16:24:56 spiegel Exp $
+;; $Id: vc-cvs.el,v 1.15 2001/01/09 14:48:25 fx Exp $
 
 ;; This file is part of GNU Emacs.
 
@@ -28,7 +28,7 @@
 
 ;;; Code:
 
-;;; 
+;;;
 ;;; Customization options
 ;;;
 
@@ -71,7 +71,7 @@
   :version "21.1"
   :group 'vc)
 
-
+
 ;;;
 ;;; Internal variables
 ;;;
@@ -82,9 +82,9 @@
     ("Sep" . 9) ("Oct" . 10) ("Nov" . 11) ("Dec" . 12))
   "Local association list of month numbers.")
 
-
+
 ;;;
-;;; State-querying functions 
+;;; State-querying functions
 ;;;
 
 ;;;###autoload (defun vc-cvs-registered (f)
@@ -176,11 +176,11 @@
 (defun vc-cvs-mode-line-string (file)
   "Return string for placement into the modeline for FILE.
 Compared to the default implementation, this function handles the
-special case of a CVS file that is added but not yet comitted."
+special case of a CVS file that is added but not yet committed."
   (let ((state   (vc-state file))
 	(rev     (vc-workfile-version file)))
     (cond ((string= rev "0")
 	   ;; A file that is added but not yet comitted.
 	   "CVS @@")
 	  ((or (eq state 'up-to-date)
 	       (eq state 'needs-patch))
@@ -205,7 +205,7 @@
 		      )))
     (if state (concat "(" state ")"))))
 
-
+
 ;;;
 ;;; State-changing functions
 ;;;
@@ -223,7 +223,7 @@
 		     (if (stringp vc-cvs-register-switches)
 			 (list vc-cvs-register-switches)
 		       vc-cvs-register-switches))))
-    
+
       (apply 'vc-do-command nil 0 "cvs" file
 	     "add"
 	     (and comment (string-match "[^\t\n ]" comment)
@@ -308,11 +308,11 @@
 	  ;; the file in the right place.
 	  (setq default-directory (file-name-directory filename))
 	  (if workfile
-	      (let ((failed t) 
+	      (let ((failed t)
                     (backup-name (if (string= file workfile)
                                      (car (find-backup-file-name filename)))))
                 (when backup-name
-                  (copy-file filename backup-name 
+                  (copy-file filename backup-name
                              'ok-if-already-exists 'keep-date)
                   (unless (file-writable-p filename)
                     (set-file-modes filename
@@ -331,9 +331,9 @@
                                  "-p"
                                  switches)))
 		      (setq failed nil))
-		  (if failed 
+		  (if failed
                       (if backup-name
-                          (rename-file backup-name filename 
+                          (rename-file backup-name filename
                                        'ok-if-already-exists)
                         (if (file-exists-p filename)
                             (delete-file filename)))
@@ -441,7 +441,7 @@
             (error "Couldn't analyze cvs update result")))
       (message "Merging changes into %s...done" file))))
 
-
+
 ;;;
 ;;; History functions
 ;;;
@@ -504,8 +504,8 @@
                    (and oldvers (concat "-r" oldvers))
                    (and newvers (concat "-r" newvers))
                    diff-switches-list))
-      (if (vc-cvs-stay-local-p file) 
-          1 ;; async diff, pessimistic assumption 
+      (if (vc-cvs-stay-local-p file)
+          1 ;; async diff, pessimistic assumption
         status))))
 
 (defun vc-cvs-annotate-command (file buffer &optional version)
@@ -541,7 +541,7 @@
 	  (beginning-of-line nil)
 	  (vc-cvs-annotate-difference (point))))))
 
-
+
 ;;;
 ;;; Snapshot system
 ;;;
@@ -586,7 +586,7 @@
 		  (vc-resynch-buffer file t t))))
 	  (forward-line 1))))))
 
-
+
 ;;;
 ;;; Miscellaneous
 ;;;
@@ -602,7 +602,7 @@
     (re-search-forward "\\$[A-Za-z\300-\326\330-\366\370-\377]+\
 \\(: [\t -#%-\176\240-\377]*\\)?\\$" nil t)))
 
-
+
 ;;;
 ;;; Internal functions
 ;;;
@@ -731,7 +731,7 @@
     (vc-file-setprop file 'vc-workfile-version (match-string 1))
     (vc-file-setprop file 'vc-checkout-time 0)
     (if set-state (vc-file-setprop file 'vc-state 'edited)))))
-           
+
 (provide 'vc-cvs)
 
 ;;; vc-cvs.el ends here
@@ -176,11 +176,11 @@
 	(rev     (vc-workfile-version file)))
     (cond ((string= rev "0")
-	   ;; A file that is added but not yet comitted.
+	   ;; A file that is added but not yet committed.
 	   "CVS @@")
 	  ((or (eq state 'up-to-date)